This optional binding (as described in the ethernet DT bindings doc)
directs the netdev to the phydev to use. This is useful for a phy
chip that has >1 phy in it, and two netdevs are using the same phy
chip (i.e. the second mac's phy lives on the first mac's MDIO bus)

The devicetree snippet would look something like this:

ethernet@feedf00d {
        ...
        phy-handle = <&phy0> // the first netdev is physically wired to phy0
        ...
        phy0: phy@0 {
                ...
                reg = <0x0> // MDIO address 0
                ...
        }
        phy1: phy@1 {
                ...
                reg = <0x1> // MDIO address 1
                ...
        }
...
}

ethernet@deadbeef {
        ...
        phy-handle = <&phy1> // tells the driver to use phy1 on the
                                                 // first mac's mdio bus (it's 
wired thusly)
        ...
}

The work done to add the phy_node in the first place (dacdbb4dfc1a1:
"net: macb: add fixed-link node support") will consume the
device_node (if found).

Signed-off-by: Brad Mouring <brad.mour...@ni.com>
---
 drivers/net/ethernet/cadence/macb_main.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/drivers/net/ethernet/cadence/macb_main.c 
b/drivers/net/ethernet/cadence/macb_main.c
index db1dc301bed3..d09bd43680b3 100644
--- a/drivers/net/ethernet/cadence/macb_main.c
+++ b/drivers/net/ethernet/cadence/macb_main.c
@@ -488,10 +488,12 @@ static int macb_mii_probe(struct net_device *dev)
                        }
                        bp->phy_node = of_node_get(np);
                } else {
-                       /* fallback to standard phy registration if no phy were
-                        * found during dt phy registration
+                       bp->phy_node = of_parse_phandle(np, "phy-handle", 0);
+                       /* fallback to standard phy registration if no
+                        * phy-handle was found nor any phy found during
+                        * dt phy registration
                         */
-                       if (!phy_find_first(bp->mii_bus)) {
+                       if (!bp->phy_node && !phy_find_first(bp->mii_bus)) {
                                for (i = 0; i < PHY_MAX_ADDR; i++) {
                                        struct phy_device *phydev;
 
-- 
2.16.2

Reply via email to